@@ -26,8 +26,9 @@
 #' @rdname as_tbl_graph
 #' @name as_tbl_graph
 as_tbl_graph.tidy_dagitty <- function(x, directed = TRUE, ...) {
-  x <- dplyr::filter(x, !is.na(to))
-  tidygraph::as_tbl_graph(x$data, directed = directed, ...)
+  pull_dag_data(x) %>%
+    dplyr::filter(!is.na(to)) %>%
+    tidygraph::as_tbl_graph(directed = directed, ...)
 }
 
 #' @export
